#####################
Patch-based pipelines
#####################

When the GPU can't fit a whole volume, patches can be extracted from the
volumes for training and testing.

.. image:: ../../images/diagram_patches.svg
   :alt: Training with patches


.. toctree::
   :maxdepth: 3

   patch_training.rst
   patch_inference.rst
